@@ -42,13 +42,13 @@
 #define MSGLEN                        256   /* characters */
 
 /* variables */
-static Monitor *monitor;
-static GtkWidget   * g_numproc            = NULL;
-static GtkWidget   * g_threshold          = NULL;
-static GtkWidget   * g_updates            = NULL;
-static GtkWidget   * g_exclusions         = NULL;
-static GtkWidget   * g_show_nice          = NULL;
-static GtkWidget   * g_show_percent       = NULL;
+static Monitor   * monitor;
+static GtkWidget * gtk_numproc            = NULL;
+static GtkWidget * gtk_threshold          = NULL;
+static GtkWidget * gtk_updates            = NULL;
+static GtkWidget * gtk_exclusions         = NULL;
+static GtkWidget * gtk_show_nice          = NULL;
+static GtkWidget * gtk_show_percent       = NULL;
 
 struct entries {
     Panel           *panel;
@@ -60,16 +60,18 @@ struct process *best[MAXITEMS];
 
 /* variables */
 static GtkTooltips *panel_tooltip = NULL;
-static gint style_id;
-static gint mouseIn = -1;
-static gint display_tooltip = FALSE;
+static gint g_style_id;
+static gint g_mouseIn = -1;
+static gint mouseInDelay = 0;
+static gint g_display_tooltip = FALSE;
 
-static gint threshold = 0;     
-static gint numproc = 2;      /* start with 2 procesess */
-static gint local_updates = MAX_UPDATES_PER_TAU;     
+static gint g_threshold = 0;     
+static gint g_numproc = 2;      /* start with 2 procesess */
+static gint g_local_updates = MAX_UPDATES_PER_TAU;     
 
-static gint master_modulus=MAX_UPDATES_PER_TAU;
-static gint global_update_HZ = 0;     
+static gint g_master_modulus  = MAX_UPDATES_PER_TAU;
+static gint g_update_HZ = 0;     
+static gint g_show_percent = 0;
 
 #ifdef GKRELLM2
 static GkrellmTicks *GKp;
@@ -82,11 +84,10 @@ static gchar s_exclusion [MSGLEN]; //string to exclude rexexp from proc list
 /* global show_nice_processes variable */
 extern int show_nice_processes;
 extern enum modes pluginMode;
-static gchar tooltip_text[MSGLEN]; //will hold the tooltip onmouseover
+static char *g_pluginModeText[] = {"CPU:     \n", "MEM:     \n", "IO:      \n"};
+static gchar g_tooltip_text[MSGLEN]; //will hold the tooltip onmouseover
 
-int show_percent;
-int tokill_i;
-int tokill_pid;
+pid_t g_tokill_pid;
 
 
 static int  (*find_top_three)(struct process **best);
@@ -105,6 +106,7 @@ static gint             gkrelltopd_version_rev;
 
 static void top_client_setup(gchar *line)
 {
+    fprintf(stderr,"line %s", line);
     if (!strcmp(line, "available"))
         gkrelltop_server_available = TRUE;
     else if (!strncmp(line, "version ", 8))
@@ -112,15 +114,16 @@ static void top_client_setup(gchar *line)
              &gkrelltopd_version_minor, &gkrelltopd_version_rev);
 }
 
-/* show numproc panels and hide the other MAXITEMS-numproc panels */
+/* show numproc panels and hide the rest of the panels */
 static void check_numproc()
 {
-    gint i;
-    for (i=0;i<numproc;i++) {
-        gkrellm_panel_show( entry[i].panel );
-    }
-    for(; i<MAXITEMS; i++){
-        gkrellm_panel_hide( entry[i].panel );
+    gint i = 0;
+    while(i < MAXITEMS) {
+        if(i < g_numproc)
+            gkrellm_panel_show( entry[i].panel );
+        else
+            gkrellm_panel_hide( entry[i].panel );
+        i++;
     }
 }
 
@@ -136,7 +139,7 @@ static void top_client_data_from_server(gchar *line)
     if (!strcmp(which, "ntop"))
     {
         cache_ntop = atoi(item);
-        if (cache_ntop < 0 || cache_ntop > 3)
+        if (cache_ntop < 0 || cache_ntop > MAXITEMS)
             cache_ntop = 0;
             for (n = cache_ntop; n < MAXITEMS; ++n)
             {
@@ -159,7 +162,7 @@ static gint gkrelltop_client_process_find_top_three(struct process **best)
 {
     gint i;
 
-    for (i = 0; i < numproc; ++i)
+    for (i = 0; i < g_numproc; ++i)
         best[i] = &cache_best[i];
     return cache_ntop;
 }
@@ -183,37 +186,35 @@ static gint top_expose_event(GtkWidget * widget,
 static void top_enter_notify_event(GtkWidget * widget, 
             GdkEventCrossing * event, gpointer user_data)
 { 
-    mouseIn=GPOINTER_TO_INT(user_data); /* mark where mouse moved into */
-    display_tooltip=TRUE; /* redisplay */
+    g_mouseIn = GPOINTER_TO_INT(user_data); /* mark where mouse moved into */
+    mouseInDelay = 2; /* delay by two cycles repainting -- configurable? */
+    g_display_tooltip = TRUE; /* redisplay */
 
     /* immediately display the tooltip instead of waiting for update */
-    gtk_tooltips_set_tip(panel_tooltip, widget, tooltip_text, ""); 
+    gtk_tooltips_set_tip(panel_tooltip, widget, g_tooltip_text, ""); 
 }
 
 /* upon signal motion_notify_event */
 static void top_motion_notify_event(GtkWidget * widget, 
                 GdkEventCrossing * event, gpointer user_data)
 {
-    display_tooltip=TRUE; /* redisplay */
+    g_display_tooltip = TRUE; /* redisplay */
 }
 
 /* upon signal leave_notify_event */
 static void top_leave_notify_event(GtkWidget * widget, 
             GdkEventCrossing * event, gpointer user_data)
 {
-    mouseIn = -1;        /* change status; mouse is outside */
+    g_mouseIn = -1;        /* change status; mouse is outside */
 }
 
 static void top_ok_dialog(GtkWidget *widget, GtkWidget *dialog)
 {
-    /* at this point send the signal to tokill_pid even though 
-     * it might not hold anymore that
-     *    (best[tokill_i] && best[tokill_i]->pid == tokill_pid) 
-     * that is it might not hold that it is the most active process anylonger
+    /* at this point send the signal to g_tokill_pid even though 
      * it might be a better idea to copy it in the framebuffer and the 
      * user kills it from a terminal.
      */
-    kill(tokill_pid,9);
+    kill(g_tokill_pid, 9);
 
     gtk_widget_destroy(dialog);
 }
@@ -223,7 +224,7 @@ static void top_close_dialog(GtkWidget *widget, GtkWidget *dialog)
     gtk_widget_destroy(dialog);
 }
 
-static void top_message_dialog()
+static void top_message_dialog(const char * name, pid_t pid)
 {
 
     GtkWidget   *dialog;
@@ -232,12 +233,10 @@ static void top_message_dialog()
     GtkWidget   *label;
     gchar        message[MSGLEN];
 
-    /* if it has changed in the mean time */
-    if(!best[tokill_i] || best[tokill_i]->pid != tokill_pid) 
-        return;
 
-    snprintf(message,sizeof(message),"Kill process %s with pid %d?",
-                            best[tokill_i]->name,best[tokill_i]->pid);
+    g_tokill_pid = pid;
+
+    snprintf(message, sizeof(message), "Kill process %s with pid %d?",name,pid);
 
     dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title(GTK_WINDOW(dialog), "Kill process");
@@ -274,23 +273,24 @@ static void top_message_dialog()
 static void top_click_event(GtkWidget * widget, GdkEventButton * ev,
         gpointer user_data)
 {
-    if (ev->button==3) {
+    if (ev->button == 3) {
         /* show the setup window on rightclick */
         gkrellm_open_config_window(monitor);
     }
-    if (ev->button==1) {
-#if defined(LINUX)
-        pluginMode = (pluginMode == cpu) ? mem : cpu;
-#endif
-    }
-    else if (ev->button==2 && ev->type == GDK_2BUTTON_PRESS) {
+    else if (ev->button==2 && (ev->state & GDK_CONTROL_MASK || 
+                               ev->type == GDK_2BUTTON_PRESS)) {
         /* user_data has the number of the panel clicked */
         gint i=GPOINTER_TO_INT(user_data);
-        if(best[i]) {
-            tokill_i=i;
-            tokill_pid=best[i]->pid;
-            top_message_dialog();
-        }
+        if(best[i]) 
+            top_message_dialog(best[i]->name, best[i]->pid);
+
+    }
+    else { /* left click: rotate between cpu/mem/io views */
+#if defined(LINUX)
+        pluginMode++;
+        if(pluginMode > io)
+            pluginMode = cpu;
+#endif
     }
 }
 
@@ -298,15 +298,15 @@ static void top_click_event(GtkWidget * widget, GdkEventButton * ev,
  * by some other function besides update_plugin() */
 static void top_update_panels()
 {
+    if(mouseInDelay-- > 0)
+        return;
+
     gchar display_text[64];
-
-    gint i = 0;
-    gint n;
-
     bzero(display_text,sizeof(display_text));
 
-    n=0;
-    tooltip_text[0] = '\0';
+    gint n = 0;
+    gint i = 0;
+    g_tooltip_text[0] = '\0';
     for (i = 0; i < MAXITEMS; i++) {
         best[i]=0;
     }
@@ -316,7 +316,7 @@ static void top_update_panels()
     |  isn't, make sure user can know displayed data is from local host.
     */
     if (!gkrelltop_server_available && gkrellm_client_mode())
-        snprintf(tooltip_text, sizeof(tooltip_text), "Localhost: %s\n\n",
+        snprintf(g_tooltip_text, sizeof(g_tooltip_text), "Localhost: %s\n\n",
             gkrellm_get_hostname());
 #endif
 
@@ -324,45 +324,60 @@ static void top_update_panels()
     * a gkrellmd server or locally via top_three.c
     */
     n = (*find_top_three)(best);    /* Find the top three processes */
-    //static int count=0; printf("%d call do update(), n=%d\n",count++,n);
 
-    /* cant have more than 3, some error occured */
+    /* cant have more than MAXITEMS, some error occured */
     if (n > MAXITEMS) {
         return;
     }
 
-    if(n>0 && display_tooltip)
-        strncat(tooltip_text,(pluginMode == cpu) ? "CPU:\n" : "MEM:\n",
-                             sizeof(tooltip_text)-strlen(tooltip_text));
-    
+    if(g_display_tooltip)
+        strncat(g_tooltip_text,g_pluginModeText[pluginMode],
+                 sizeof(g_tooltip_text)-strlen(g_tooltip_text));
 
-    for (i = 0; i < n; i++) {
-        if(best[i]->amount < threshold ) 
+    for (i = 0; i < n; i++) 
+    {
+        if(best[i]->amount < g_threshold ) 
             break; //the next for will fill in with blanks
 
-        if(show_percent)
+        if(g_show_percent)
             snprintf(display_text, sizeof(display_text),
                 "%.0f%c %s", best[i]->amount,'%',best[i]->name);
         else 
             snprintf(display_text, sizeof(display_text)," %s", best[i]->name);
 
-        gchar ch = (i < n-1) ? '\n' : ' ' ; /* prnt \n only for 1 and 2*/
-        gchar tmp[MSGLEN];
-        snprintf(tmp,sizeof(tmp), "%d: %4.1f%c  %6.2d  %.30s%c", 
-            i+1, best[i]->amount, '%', best[i]->pid, best[i]->name, ch);
 
-        if(display_tooltip) /* append at the end of tooltip_text */
-            strncat(tooltip_text,tmp,sizeof(tooltip_text)-strlen(tooltip_text));
+        if(g_display_tooltip) /* append at the end of g_tooltip_text */
+        { 
+            gchar tmp[MSGLEN];
+            gchar ch = (i < n-1) ? '\n' : ' ' ; /* prnt \n only for 1 and 2*/
+
+            if(pluginMode == cpu)
+                snprintf(tmp,sizeof(tmp), "%d: %4.1f%c  %6.2d  %.30s%c", 
+                    i+1, best[i]->amount, '%', best[i]->pid, best[i]->name, ch);
+            else if(pluginMode == mem)
+                snprintf(tmp,sizeof(tmp), "%d: %4.1f%c %6.2dMB %6.2d  %.30s%c", 
+                    i+1, best[i]->amount, '%', best[i]->rss/MEG,
+                    best[i]->pid, best[i]->name, ch);
+            else if(pluginMode == io)
+                snprintf(tmp,sizeof(tmp), 
+                    "%d: %4.1f%c R:%6.0fKB W:%6.0fKB %6.2d  %.30s%c", 
+                    i+1, best[i]->amount, '%', 
+                    (float)(best[i]->io_read - best[i]->previous_io_read)/KIL,
+                    (float)(best[i]->io_write - best[i]->previous_io_write)/KIL,
+                    best[i]->pid, best[i]->name, ch);
+
+            strncat(g_tooltip_text,tmp,sizeof(g_tooltip_text)-strlen(g_tooltip_text));
+        }
 
         /* set the panels with the top three processes */
         gkrellm_draw_decal_text(entry[i].panel, 
-            entry[i].decal_text,display_text, 0);
+                entry[i].decal_text,display_text, 0);
 
         /* best[i]->amount determines the ofset in the pixmap */
         gkrellm_update_krell(entry[i].panel, 
-            entry[i].krell_meter, best[i]->amount ); 
+                entry[i].krell_meter, best[i]->amount ); 
     } // end for
-    for(;i<numproc;i++) { //take care of the rest of the entries, 
+    for(; i< g_numproc; i++) { //take care of the rest of the entries, 
                           //i set in the previous for loop
 
         /* set the panels with the top three processes, or with blank */
@@ -371,14 +386,14 @@ static void top_update_panels()
     } //end for
 
     /* update the tooltip with the recent proceses in the list */
-    if (mouseIn >= 0 && display_tooltip) { 
+    if (g_mouseIn >= 0 && g_display_tooltip) { 
         /* display  tooltip */
-       gtk_tooltips_set_tip(panel_tooltip, entry[mouseIn].panel->drawing_area,
-                                                   tooltip_text, tooltip_text); 
+       gtk_tooltips_set_tip(panel_tooltip, entry[g_mouseIn].panel->drawing_area,
+                                               g_tooltip_text, g_tooltip_text); 
     }
 
     //draw the newly updated pannel
-    for (i=0; i<numproc; i++) {
+    for (i=0; i < g_numproc; i++) {
         gkrellm_draw_panel_layers(entry[i].panel);
     }
 }
@@ -389,24 +404,24 @@ static void recompute_modulus()
     static gint old_local_updates=0;
 
     gint itmp=gkrellm_update_HZ();
-    /* only recompute the modulus if the value for global_update_HZ has changed
+    /* only recompute the modulus if the value for g_update_HZ has changed
      * or the value for the local_updates has changed
      */
-    if(global_update_HZ!=itmp || old_local_updates != local_updates) {
-        old_local_updates=local_updates;
+    if(g_update_HZ != itmp || old_local_updates != g_local_updates) {
+        old_local_updates = g_local_updates;
 
         if(itmp > 0 && itmp < MAX_UPDATES_PER_TAU) 
-            global_update_HZ = itmp;
+            g_update_HZ = itmp;
         else 
-            global_update_HZ = MAX_UPDATES_PER_TAU;
+            g_update_HZ = MAX_UPDATES_PER_TAU;
 
-        master_modulus=(gint)(global_update_HZ*UPDATE_TAU/local_updates);
-        if(master_modulus<1) master_modulus=1;
+        g_master_modulus=(gint)(g_update_HZ*UPDATE_TAU/g_local_updates);
+        if(g_master_modulus < 1) g_master_modulus = 1;
     }
 }
 
 /* the update_plugin function is called every timer_tick 
- * which is determined by the global_update_HZ() function
+ * which is determined by the g_update_HZ() function
  */ 
 static void top_update_plugin()
 {
@@ -415,7 +430,7 @@ static void top_update_plugin()
 #ifdef GKRELLM2
     if (GKp->five_second_tick) {
         /* set the global update_HZ variable every five second ticks 
-         * so if user changed the global_update_HZ, we will have 
+         * so if user changed the g_update_HZ, we will have 
          * the latest value 
          * */
         recompute_modulus();
@@ -426,25 +441,25 @@ static void top_update_plugin()
  * from the general options tab of gkrellmwith a range between 2-20 hertz
  */
 
-    if ( (GKp->timer_ticks % master_modulus) == 0 ) { 
+    if ( (GKp->timer_ticks % g_master_modulus) == 0 ) { 
         top_update_panels();  /* update the panels */
     }   
 
 #else
     if (GK.five_second_tick) {
         /* set the global update_HZ variable every five second ticks 
-         * so if user changed the global_update_HZ, we will have 
+         * so if user changed the g_update_HZ, we will have 
          * the latest  value 
          * */
-        global_update_HZ=gkrellm_update_HZ();
-        if(global_update_HZ <=0 || global_update_HZ > 10) 
-            global_update_HZ=5;
+        g_update_HZ = gkrellm_update_HZ();
+        if(g_update_HZ <= 0 || g_update_HZ > 10) 
+            g_update_HZ=5;
     }
 
-    if ((GK.timer_ticks % (gint)(global_update_HZ*UPDATE_TAU)) == local_updates)
+    if ((GK.timer_ticks % (gint)(g_update_HZ*UPDATE_TAU)) == g_local_updates)
     {
         top_update_panels();  /* update the panels */
-    }   //if gk.second_tick
+    }   
 #endif
 
 }
@@ -468,9 +483,9 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
         }
     }
 
-    style = gkrellm_meter_style(style_id);  /* set style of the meter */
+    style = gkrellm_meter_style(g_style_id);  /* set style of the meter */
 
-    ts = gkrellm_meter_textstyle(style_id); //smaller font e brighter col 
+    ts = gkrellm_meter_textstyle(g_style_id); //smaller font e brighter col 
     ts->font=gkrellm_default_font(0); //set to small_font
 
     GkrellmPiximage *image = NULL;
@@ -482,8 +497,8 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
                 KRELL_EXPAND_LEFT, 1,  //expansion type and movement steping
                 0, 0);   //left and right margins, should be close to 0
 
-    for (i=0; i<MAXITEMS; i++) {
-
+    for (i=0; i<MAXITEMS; i++) 
+    {
         /* create the krell--the image with the color */
         entry[i].krell_meter = gkrellm_create_krell(entry[i].panel,image,style);
         gkrellm_set_krell_full_scale(entry[i].krell_meter, 100, 1);
@@ -496,19 +511,19 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
          * y=2 and left margin x=-1 of the style.
          */
         entry[i].decal_text = gkrellm_create_decal_text(entry[i].panel, 
-                                                    "Ayl0",ts,style,-1,2,-1);
+                "Ayl0", ts, style, -1, 2, -1);
 
-        y=entry[i].decal_text->y+entry[i].decal_text->h-3;
+        y=entry[i].decal_text->y + entry[i].decal_text->h - 3;
 
         /* offset the krell image under the text decal */
-        gkrellm_move_krell_yoff(entry[i].panel,entry[i].krell_meter,y);
+        gkrellm_move_krell_yoff(entry[i].panel, entry[i].krell_meter, y);
         
         /* needed if the krell goes on top of the text */
         gkrellm_decal_on_top_layer(entry[i].decal_text, TRUE);
     }
 
     for (i=0; i<MAXITEMS; i++) {
-        /* Configure the panel to hold the above created decals, and create it.  */
+        /* Configure the panel to hold the above created decals, and create it*/
         gkrellm_panel_configure(entry[i].panel, "", style);
         gkrellm_panel_create(vbox, monitor, entry[i].panel);
     }
@@ -516,8 +531,8 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
 
     /* connect the signals */
     
-    if (first_create) {
-        
+    if (first_create) 
+    {
       for (i=0; i<MAXITEMS; i++) {
         gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area), 
           "expose_event", (GtkSignalFunc) top_expose_event, entry[i].panel);
@@ -532,7 +547,6 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
         gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
           "motion_notify_event" ,(GtkSignalFunc) top_motion_notify_event, NULL);
 
-        
         gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
             "button_press_event", (GtkSignalFunc) top_click_event, 
                 GINT_TO_POINTER(i));
@@ -556,10 +570,10 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
     }
 
     /* set the local_updates after reading from the config */
-    if(local_updates > MAX_UPDATES_PER_TAU) 
-        local_updates = MAX_UPDATES_PER_TAU;
-    else if(local_updates <= 0) 
-        local_updates = 1; 
+    if(g_local_updates > MAX_UPDATES_PER_TAU) 
+        g_local_updates = MAX_UPDATES_PER_TAU;
+    else if(g_local_updates <= 0) 
+        g_local_updates = 1; 
 
     recompute_modulus();
     check_numproc();
@@ -592,7 +606,7 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
     label = gtk_label_new(_("Number of top processes to show (max 3):"));
     gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-    gkrellm_spin_button(hbox, &g_numproc, (gfloat) numproc, 1.0, 
+    gkrellm_spin_button(hbox, &gtk_numproc, (gfloat) g_numproc, 1.0, 
              MAXITEMS, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
 
 
@@ -600,14 +614,14 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
     label = gtk_label_new(_("Show only processes above (in %):"));
     gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-    gkrellm_spin_button(hbox, &g_threshold, (gfloat) threshold, 
+    gkrellm_spin_button(hbox, &gtk_threshold, (gfloat) g_threshold, 
            0.0, 100.0, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
 
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
     label = gtk_label_new(_("Frequency of updates (in 5 seconds):"));
     gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-    gkrellm_spin_button(hbox, &g_updates, (gfloat) local_updates, 1.0, 
+    gkrellm_spin_button(hbox, &gtk_updates, (gfloat) g_local_updates, 1.0, 
             MAX_UPDATES_PER_TAU, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
 
 
@@ -615,12 +629,12 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
     hbox = gtk_hbox_new(FALSE, 0);
     label = gtk_label_new(_("Exclusions (as regular expression ex: ^idle) : "));
     gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
-    g_exclusions = gtk_entry_new();
+    gtk_exclusions = gtk_entry_new();
 
     if (strlen(s_exclusion) > 0)
-        gtk_entry_set_text((GtkEntry*)g_exclusions, s_exclusion);
+        gtk_entry_set_text((GtkEntry*)gtk_exclusions, s_exclusion);
 
-    gtk_box_pack_start(GTK_BOX(hbox),g_exclusions,TRUE,TRUE,8);
+    gtk_box_pack_start(GTK_BOX(hbox),gtk_exclusions,TRUE,TRUE,8);
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
 
     gtk_box_pack_start(GTK_BOX(vbox1), gtk_hseparator_new(), FALSE, FALSE, 8);
@@ -628,13 +642,13 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
     /* nice processes */
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-    gkrellm_check_button(hbox, &g_show_nice, show_nice_processes, TRUE, 0,
+    gkrellm_check_button(hbox, &gtk_show_nice, show_nice_processes, TRUE, 0,
       _("Show nice processes"));
 
     /* percentage in front of process name */
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-    gkrellm_check_button(hbox, &g_show_percent, show_percent, TRUE, 0,
+    gkrellm_check_button(hbox, &gtk_show_percent, g_show_percent, TRUE, 0,
       _("Show percentage in front of process names"));
 
     /* could have process activity as chart but many processes are ephemeral
@@ -643,9 +657,9 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
 
     /* -- About -- */
     about_text = g_strdup_printf(
-      "gkrelltop version 2.2.11\n"
+      "gkrelltop version 2.2.13\n"
       "gkrellm top plugin\n"
-      "Copyright (c) 2007 Adi Zaimi\n"
+      "Copyright (c) 2007-9 Adi Zaimi\n"
       "adizaimi@users.sourceforge.net\n"
       "http://gkrelltop.sourceforge.net\n\n"
       "Released under the GNU Public License");
@@ -676,26 +690,26 @@ static void top_apply_config()
 {
     GtkSpinButton *spin;
     
-    spin = GTK_SPIN_BUTTON(g_numproc);
+    spin = GTK_SPIN_BUTTON(gtk_numproc);
     //set the numproc
-    numproc=gtk_spin_button_get_value_as_int(spin);
+    g_numproc=gtk_spin_button_get_value_as_int(spin);
     check_numproc();
 
-    spin = GTK_SPIN_BUTTON(g_threshold);
+    spin = GTK_SPIN_BUTTON(gtk_threshold);
     //set the threshold
-    threshold = gtk_spin_button_get_value_as_int(spin);
+    g_threshold = gtk_spin_button_get_value_as_int(spin);
     //set the show_nice_processes variable from the checkbox
-    show_nice_processes = GTK_TOGGLE_BUTTON(g_show_nice)->active;
-    show_percent = GTK_TOGGLE_BUTTON(g_show_percent)->active;
-    spin = GTK_SPIN_BUTTON(g_updates);
+    show_nice_processes = GTK_TOGGLE_BUTTON(gtk_show_nice)->active;
+    g_show_percent = GTK_TOGGLE_BUTTON(gtk_show_percent)->active;
+    spin = GTK_SPIN_BUTTON(gtk_updates);
     //set how often to update the top list
-    local_updates = gtk_spin_button_get_value_as_int(spin);
+    g_local_updates = gtk_spin_button_get_value_as_int(spin);
 
     //if the exclusions is set, build the exclusion_expression variable
-    if (g_exclusions ) 
+    if (gtk_exclusions ) 
     {
         
-        g_strlcpy(s_exclusion, gtk_entry_get_text((GtkEntry *) g_exclusions),
+        g_strlcpy(s_exclusion, gtk_entry_get_text((GtkEntry *) gtk_exclusions),
                                                          sizeof(s_exclusion) );
         top_apply_exclusion();
     }
@@ -705,10 +719,10 @@ static void top_apply_config()
     }
 
     /* safety check */
-    if(local_updates > MAX_UPDATES_PER_TAU) 
-        local_updates = MAX_UPDATES_PER_TAU;
-    else if(local_updates <= 0) 
-        local_updates = 1; 
+    if(g_local_updates > MAX_UPDATES_PER_TAU) 
+        g_local_updates = MAX_UPDATES_PER_TAU;
+    else if(g_local_updates <= 0) 
+        g_local_updates = 1; 
 
     recompute_modulus();
 
@@ -721,13 +735,13 @@ static void top_save_config(FILE *f)
     PLUGIN_CONFIG_KEYWORD  config_keyword  data
     */
 
-    fprintf(f, "%s numproc %d\n", PLUGIN_CONFIG_KEYWORD, numproc);
-    fprintf(f, "%s threshold %d\n", PLUGIN_CONFIG_KEYWORD, threshold);
+    fprintf(f, "%s numproc %d\n", PLUGIN_CONFIG_KEYWORD, g_numproc);
+    fprintf(f, "%s threshold %d\n", PLUGIN_CONFIG_KEYWORD, g_threshold);
     fprintf(f, "%s show_nice_processes %d\n", 
             PLUGIN_CONFIG_KEYWORD, show_nice_processes);
 
-    fprintf(f, "%s show_percent %d\n", PLUGIN_CONFIG_KEYWORD, show_percent);
-    fprintf(f, "%s local_updates %d\n", PLUGIN_CONFIG_KEYWORD, local_updates);
+    fprintf(f, "%s show_percent %d\n", PLUGIN_CONFIG_KEYWORD, g_show_percent);
+    fprintf(f, "%s local_updates %d\n", PLUGIN_CONFIG_KEYWORD, g_local_updates);
     fprintf(f, "%s exclusion_expression %s\n", 
             PLUGIN_CONFIG_KEYWORD, s_exclusion);
 
@@ -745,19 +759,19 @@ static void top_load_config(gchar *config_line)
     }
 
     if ( strcmp(config_keyword, "numproc")==0 ) {
-        sscanf(config_data, "%d", & numproc);
+        sscanf(config_data, "%d", &g_numproc);
     }
     else if ( strcmp(config_keyword, "threshold")==0 ) {
-        sscanf(config_data, "%d", & threshold);
+        sscanf(config_data, "%d", &g_threshold);
     }
     else if (strcmp(config_keyword, "show_nice_processes")==0) {
-        sscanf(config_data, "%d", & show_nice_processes);
+        sscanf(config_data, "%d", &show_nice_processes);
     }
     else if (strcmp(config_keyword, "show_percent")==0) {
-        sscanf(config_data, "%d", & show_percent);
+        sscanf(config_data, "%d", &g_show_percent);
     }
     else if (strcmp(config_keyword, "local_updates")==0) {
-        sscanf(config_data, "%d", & local_updates);
+        sscanf(config_data, "%d", &g_local_updates);
     }
     else if (strcmp(config_keyword, "exclusion_expression")==0) {
         sscanf(config_data, "%s", s_exclusion);
@@ -793,16 +807,17 @@ static Monitor top_plugin_mon = {
 /* initialise plugin -- required */
 Monitor *init_plugin()
 {
-    style_id = gkrellm_add_meter_style(&top_plugin_mon, STYLE_NAME);
+    g_style_id = gkrellm_add_meter_style(&top_plugin_mon, STYLE_NAME);
 
 #ifdef    GKRELLM_HAVE_CLIENT_MODE_PLUGINS
     gkrellm_client_plugin_get_setup(GKRELLTOP_SERVE_NAME, top_client_setup);
 
+    fprintf(stderr,"available %d", gkrelltop_server_available);
     if (gkrelltop_server_available)
     {
         find_top_three = gkrelltop_client_process_find_top_three;
         gkrellm_client_plugin_serve_data_connect(&top_plugin_mon,
-        GKRELLTOP_SERVE_NAME, top_client_data_from_server);
+                GKRELLTOP_SERVE_NAME, top_client_data_from_server);
     }
     else
         find_top_three = gkrelltop_process_find_top_three;
