@@ -38,7 +38,7 @@
 
 
 /* process structure for use by gkrellm 
- * store processes in a doubly linked list */
+ * store processes in a linked list */
 struct process {        
     struct process *next;
     struct process *previous;
@@ -53,16 +53,18 @@ struct process {
     int vsize;
     int rss;
     int time_stamp;
-    int counted;
+    int include;
     int changed;
+#if defined(LINUX)
+    int io_read;
+    int io_write;
+    int previous_io_read;
+    int previous_io_write;
+#endif              /* defined(PARANOID) */
 };
 
-struct top_struct {
-    int diff_cpu;
-
-};
-
-enum modes {cpu, mem};
+enum modes {cpu, mem, io};
+enum { KIL = 1<<10, MEG = 1<<20 }; 
 
 /* functions defined */
 int gkrelltop_process_find_top_three(struct process **);
